Name:           linbox
Version:        1.1.6
Release:        6%{?dist}
Summary:        C++ Library for High-Performance Linear Algebra
Group:          Development/Libraries
License:        LGPLv2
URL:            http://www.linalg.org/
Source0:        http://www.linalg.org/linbox-%{version}.tar.gz
# send upstream via mail Oct 17 2009
# Patch0 for respecting destdir, when installing the docs
Patch0:         %{name}-respect-destdir.diff
# send upstream via mail Oct 17 2009
# Patch1 for deleting double named headers in Makefiles
# if not applied 'install' will complain and break 'make install'
Patch1:         %{name}-double-named.diff
# Patch2 for emitting --cflags --lflags in one command
# if not applied only one command can be used at the same time
Patch2:         %{name}-cflags-lflags.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  atlas-devel
BuildRequires:  givaro-devel
BuildRequires:  gmp-devel
BuildRequires:  ntl-devel

BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  libtool
BuildRequires:  tex(latex)

%description
LinBox is a C++ template library for exact, high-performance linear
algebra computation with dense, sparse, and structured matrices over
the integers and over finite fields.


%package        devel
Summary:        Development libraries/headers for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}


%description    devel
Headers and libraries for development with %{name}.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch


%description    doc
Documentation for %{name}.


%prep
%setup -q
%patch0
%patch1
%patch2
find . -type f -name '*.C' | xargs chmod 0644
find . -type f -name '*.h' | xargs chmod 0644


%build
# Rebuild Makefile.in's from Makefile.am's, because our Patch0 fixes the
# Makefile.am to respect destdir.
aclocal -I macros
automake
%configure --enable-doc --with-givaro=yes --with-ntl=yes \
    --with-blas="%{_libdir}/atlas" --enable-shared \
    --enable-sage --enable-optimization --enable-drivers \
    --with-doxygen=yes --disable-rpath --disable-static

# Remove stupid rpaths
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -f %{buildroot}%{_libdir}/*.la

# Remove docs that are installed in the wrong place
rm -rf %{buildroot}%{_prefix}/doc


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%check
make -C tests check


%clean
rm -rf %{buildroot}


%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%{_libdir}/*.so.*


%files doc
%defattr(-,root,root,-)
%doc doc/linbox-html/*


%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}
%{_libdir}/*.so
%{_bindir}/%{name}-config
%{_mandir}/man1/%{name}-config.1*


%changelog
* Mon Oct 19 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-6
- installing docs breaks naming guidelines -> install them different

* Sun Oct 18 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-5
- properly install docs and don't mv them around
- add other files to %%doc

* Sun Oct 18 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-4
- %%check
- patch for --cflags and --lflags in config

* Sat Oct 17 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-3
- patches are send upstream
- correct BuildRequires
- INSTALL is not in %%doc

* Sat Oct 17 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-2
- disable static library
- patch for double named header files
- extra doc package

* Fri Dec 12 2008 Conrad Meyer <konrad@tylerc.org> - 1.1.6-1
- Initial package.
